package com.loafle.overflow.core.model;

import java.util.ArrayList;
import java.util.List;

public class PublishMessage {
  private TargetType targetType;
  private List<String> targets;
  private PublishMessageType messageType;
  private PublishMessageBody message;

  public void setTargetType(TargetType targetType) {
    this.targetType = targetType;
  }

  public TargetType getTargetType() {
    return this.targetType;
  }

  public void setTargets(List<String> targets) {
    this.targets = targets;
  }

  public void addTarget(String target) {
    if (null == targets) {
      targets = new ArrayList<>();
    }
    targets.add(target);
  }

  public List<String> getTargets() {
    return targets;
  }

  /**
   * @return the messageType
   */
  public PublishMessageType getMessageType() {
    return messageType;
  }

  /**
   * @param messageType the messageType to set
   */
  public void setMessageType(PublishMessageType messageType) {
    this.messageType = messageType;
  }

  public void setMessage(PublishMessageBody message) {
    this.message = message;
  }

  public PublishMessageBody getMessage() {
    return message;
  }

  public static enum TargetType {
    MEMBER_SESSION("MEMBER_SESSION"), MEMBER("MEMBER"), PROBE("PROBE");

    final private String name;

    private TargetType(String name) {
      this.name = name;
    }

    public String toString() {
      return name;
    }
  }

  public static enum PublishMessageType {
    TextMessage((short) 1), BinaryMessage((short) 2), CloseMessage((short) 8), PingMessage((short) 9),
    PongMessage((short) 10),;

    private final Short value;

    /**
     * @param value
     */
    PublishMessageType(final Short value) {
      this.value = value;
    }

    public Short getValue() {
      return this.value;
    }

  }

  public static class PublishMessageBody {
    private String jsonrpc = "2.0";
    private PublishMessageBodyNotification result;

    public PublishMessageBody() {
      this.result = new PublishMessageBodyNotification();

    }

    public PublishMessageBody(String method) {
      this();
      this.result.setMethod(method);
    }

    public PublishMessageBody(String method, List<String> params) {
      this(method);
      this.result.setParams(params);
    }

    public String getJsonrpc() {
      return jsonrpc;
    }

    public void setJsonrpc(String jsonrpc) {
      this.jsonrpc = jsonrpc;
    }

    public PublishMessageBodyNotification getResult() {
      return result;
    }

    public void setResult(PublishMessageBodyNotification result) {
      this.result = result;
    }
  }

  public static class PublishMessageBodyNotification {
    private String method;
    private List<String> params;

    public String getMethod() {
      return method;
    }

    public void setMethod(String method) {
      this.method = method;
    }

    public List<String> getParams() {
      return params;
    }

    public void setParams(List<String> params) {
      this.params = params;
    }

    public void addParams(String param) {
      if (null == this.params) {
        this.params = new ArrayList<>();
      }
      this.params.add(param);
    }

  }
}
